Module base

Module base 

This module contains constants and types used throughout the code.

It includes constants for cryptographic algorithms, buffer sizes, and other parameters.

Structs

Base64KeyPair
A public-private key pair.
ClientHandshakeData
A wrapper for the Challenge, and the PeerPublicKey.
ClientKeyExchangeData
A wrapper for a local ephemeral key pair, and a peer public key.
Constant
A struct for constants.
EncryptedData
A wrapper for encrypted data, and its nonce.
ExchangeKeyPair
A public-private key pair for ephemeral key exchange.
ServerKeyExchangeData
A wrapper for the Preamble, and the EphemeralKeyPair.
TunnelDefinition
The bind address and host address for the client.

Type Aliases

Err
A helper type for errors.
Res
A helper type for results.
SharedSecret
A helper type for a shared secret.
SharedSecretNonce
A helper type for a shared secret nonce.
SharedSecretShape
A helper for the Shape of the shared secret.
Void
A helper type for void results.