pub struct ClientHandshakeData {
pub server_challenge: Challenge,
pub server_exchange_public_key: ExchangePublicKey,
}Expand description
A wrapper for the Challenge, and the PeerPublicKey.
This is mostly used as a convenience type, to hold the challenge and the peer public key together.
Fields
server_challenge: Challengeserver_exchange_public_key: ExchangePublicKeyTrait Implementations
Sourceimpl Clone for ClientHandshakeData
impl Clone for ClientHandshakeData
Sourcefn clone(&self) -> ClientHandshakeData
fn clone(&self) -> ClientHandshakeData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ClientHandshakeData
impl RefUnwindSafe for ClientHandshakeData
impl Send for ClientHandshakeData
impl Sync for ClientHandshakeData
impl Unpin for ClientHandshakeData
impl UnwindSafe for ClientHandshakeData