Constant

Struct Constant 

pub struct Constant;
A struct for constants.

Implementations

Source

impl Constant

pub const AEAD: &'static Algorithm

The AEAD algorithm used for encryption.

pub const AGREEMENT: &'static Algorithm

The alrgorithm used for key agreement.

pub const BASE64_ENGINE: GeneralPurpose = BASE64_URL_SAFE_NO_PAD

Thedefault base4 engine used for encoding and decoding keys.

pub const BINCODE_CONFIG: Configuration<BigEndian>

The default bincode engine used for encoding and decoding data across data streams.

pub const BUFFER_SIZE: usize = 130_816usize

The default buffer size (defaulting to extra large for now).

pub const CHALLENGE_SIZE: usize = 32usize

The size of a signature challenge.

pub const ENCRYPTION_OVERHEAD: usize = 256usize

The size of the encryption overhead.

pub const EXCHANGE_PUBLIC_KEY_SIZE: usize = 32usize

The size of a key exchange public key.

pub const IDENTITY_PRIVATE_KEY_LENGTH: usize = 111usize

The base64 encoded size of a key exchange private key.

pub const IDENTITY_PUBLIC_KEY_LENGTH: usize = 43usize

The base64 encoded size of a key exchange public key.

pub const KDF: Algorithm = HKDF_SHA256

The algorithm used to produce the shared secret of the key exchange.

pub const SHARED_SECRET_NONCE_SIZE: usize = 12usize

The size of the shared secret nonce.

pub const SHARED_SECRET_SIZE: usize = 32usize

The size of the shared secret.

pub const SHARED_SECRET_TAG_SIZE: usize = 16usize

The size of the shared secret encryption tag.

pub const SIGNATURE: &'static EdDSAParameters

The type of signature used for the handshake.

pub const SIGNATURE_SIZE: usize = 64usize

The size of the signature used for the handshake.

pub const TIMEOUT: Duration

The default timeout for the stale connections.