pub struct EncryptedData {
pub nonce: SharedSecretNonce,
pub data: Vec<u8>,
}Expand description
A wrapper for encrypted data, and its nonce.
This is used to encrypt and decrypt data, using the shared secret. The nonce is used to ensure that the same data encrypted multiple times will produce different ciphertexts. The data and nonce, together, are required to decrypt the data.
Fields
nonce: SharedSecretNoncedata: Vec<u8>Auto Trait Implementations
impl Freeze for EncryptedData
impl RefUnwindSafe for EncryptedData
impl Send for EncryptedData
impl Sync for EncryptedData
impl Unpin for EncryptedData
impl UnwindSafe for EncryptedData