pub struct ServerKeyExchangeData {
pub client_exchange_public_key: ExchangePublicKey,
pub client_challenge: Challenge,
pub local_exchange_private_key: EphemeralPrivateKey,
pub local_challenge: Challenge,
pub requested_remote_address: String,
pub requested_should_encrypt: bool,
pub requested_is_udp: bool,
}Expand description
A wrapper for the Preamble, and the EphemeralKeyPair.
This is mostly used as a convenience type, to hold the preamble and the ephemeral key pair together.
Fields
client_exchange_public_key: ExchangePublicKeyclient_challenge: Challengelocal_exchange_private_key: EphemeralPrivateKeylocal_challenge: Challengerequested_remote_address: Stringrequested_should_encrypt: boolrequested_is_udp: boolAuto Trait Implementations
impl Freeze for ServerKeyExchangeData
impl RefUnwindSafe for ServerKeyExchangeData
impl Send for ServerKeyExchangeData
impl Sync for ServerKeyExchangeData
impl Unpin for ServerKeyExchangeData
impl UnwindSafe for ServerKeyExchangeData