pub struct TunnelDefinition {
pub bind_address: String,
pub remote_address: String,
}Expand description
The bind address and host address for the client.
This is used to determine where to bind the socket, and where to connect to on the server side. Essentially, this is the tunnel.
Fields
bind_address: Stringremote_address: StringTrait Implementations
Sourceimpl Clone for TunnelDefinition
impl Clone for TunnelDefinition
Sourcefn clone(&self) -> TunnelDefinition
fn clone(&self) -> TunnelDefinition
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for TunnelDefinition
impl RefUnwindSafe for TunnelDefinition
impl Send for TunnelDefinition
impl Sync for TunnelDefinition
impl Unpin for TunnelDefinition
impl UnwindSafe for TunnelDefinition