pub type SharedSecretNonce = [u8; 12];Expand description
A helper type for a shared secret nonce.
These are the nonces that each end of the connection will use to encrypt and decrypt data. They are generated randomly, and are used to ensure that the same data encrypted multiple times will produce different ciphertexts.