Module buffed_stream

Module buffed_stream 

Buffed stream module.

This module contains the BuffedStream type, which is a wrapper around a stream that provides buffering and encryption/decryption functionality.

It is used to provide a bincode-centric stream that can be used to send and receive data in a more efficient manner. In addition, the AsyncRead and AsyncWrite implementations are designed to “transparently” handle encryption and decryption of the data being sent and received (for the “pump” phase of the lifecycle).

Structs

BuffedStream
BuffedStream type.
BuffedStreamReadHalf
A type for the read half of a buffed stream.
BuffedStreamWriteHalf
A type for the write half of a buffed stream.

Traits

BincodeSplit
A trait for splitting a BuffedStream into its read and write halves.

Type Aliases

BuffedDuplexStream
A type alias for a buffed DuplexStream.
BuffedTcpStream
A type alias for a buffed TcpStream.