BuffedStream

Struct BuffedStream 

pub struct BuffedStream<R, W> { /* private fields */ }
BuffedStream type.

This type is a wrapper around a stream that provides buffering and encryption/decryption functionality. It is used to provide a bincode-centric stream that can be used to send and receive data in a more efficient manner. In order to make usual future splitting more ergonomic, this type is designed to be a wrapper around the split halves.

This type is used to provide a bincode-centric stream that can be used to send and receive data so it is inadvisable to use any other methods than the push and pull methods from the protocol module.

Implementations

Source

impl<R, W> BuffedStream<R, W>

pub fn with_encryption(self, shared_secret: SharedSecret) -> Self

Sets the shared secret for the stream, and enables encryption / decryption.

Source

impl<R, W> BuffedStream<R, W>
where R: AsyncRead + Unpin, W: AsyncWrite + Unpin,

pub fn from_splits(inner_read: R, inner_write: W) -> Self

Source

impl<R> BuffedStream<R, OwnedWriteHalf>

Source

impl<W> BuffedStream<OwnedReadHalf, W>

Source

impl BuffedStream<OwnedReadHalf, OwnedWriteHalf>

pub fn take(self) -> Res<TcpStream>