ProtocolMessage

Enum ProtocolMessage 

pub enum ProtocolMessage<'a> {
    ClientPreamble(ClientPreamble<'a>),
    ServerPreamble(ServerPreamble<'a>),
    ClientAuthentication(ClientAuthentication<'a>),
    HandshakeCompletion,
    Data(&'a [u8]),
    UdpData(&'a [u8]),
    Error(ProtocolError<'a>),
    Shutdown,
}
A helper type for protocol messages.

This is the main message type for the protocol. It is used to send and receive messages over the network. It is also used to serialize and deserialize messages.

Variants



ClientPreamble(ClientPreamble<'a>)



ServerPreamble(ServerPreamble<'a>)



ClientAuthentication(ClientAuthentication<'a>)



HandshakeCompletion



Data(&'a [u8])



UdpData(&'a [u8])



Error(ProtocolError<'a>)



Shutdown

Implementations

Source

impl ProtocolMessage<'_>

pub fn fail_if_error(&self) -> Res<&Self>

Checks if the message is an error.

If it is, returns the message wrapped in an error.