Module security

Module security 

Keypair generation and resolution.

This module provides functions to generate a keypair, resolve private and public keys from files or strings, and handle errors related to key resolution.

Functions

ensure_security_files
Ensures all required security files are present and generates them if not.
generate
Generates a keypair and writes them to the specified location.
get_home
Gets the user’s home directory.
resolve_authorized_keys
Resolves to the list of authorized keys.
resolve_keypath
Computes the concrete keypath.
resolve_known_hosts
Resolves to the list of known hosts.
resolve_private_key
Resolves the private key of this instance.
resolve_public_key
Resolves the public key of this instance.