pub struct Instance<S = ConfigState> { /* private fields */ }Expand description
The server instance.
This is the main entry point for the server. It is used to prepare the server, and start it.
Implementations
Sourceimpl Instance<ConfigState>
impl Instance<ConfigState>