Ratrod
A TCP tunneler that uses public / private key authentication with encryption.
Basically, it’s ssh -L. This is useful for tunneling through a machine that doesn’t support SSH.
Re-exports
pub use tokio;
Modules
- base
- This module contains constants and types used throughout the code.
- buffed_
stream - Buffed stream module.
- connect
- This module contains the code for the client-side of the tunnel.
- protocol
- Protocol message types and serialization.
- security
- Keypair generation and resolution.
- serve
- This module implements the server-side of the protocol.
- utils
- Utility functions for the application.