This module contains constants and types used throughout the code.
It includes constants for cryptographic algorithms, buffer sizes, and other parameters.
Structs
- Base64
KeyPair - A public-private key pair.
- Client
Handshake Data - A wrapper for the Challenge, and the PeerPublicKey.
- Client
KeyExchange Data - A wrapper for a local ephemeral key pair, and a peer public key.
- Constant
- A struct for constants.
- Encrypted
Data - A wrapper for encrypted data, and its nonce.
- Exchange
KeyPair - A public-private key pair for ephemeral key exchange.
- Server
KeyExchange Data - A wrapper for the Preamble, and the EphemeralKeyPair.
- Tunnel
Definition - The bind address and host address for the client.
Type Aliases
- Err
- A helper type for errors.
- Res
- A helper type for results.
- Shared
Secret - A helper type for a shared secret.
- Shared
Secret Nonce - A helper type for a shared secret nonce.
- Shared
Secret Shape - A helper for the Shape of the shared secret.
- Void
- A helper type for void results.