pub struct Constant;Expand description
A struct for constants.
Implementations
Sourceimpl Constant
impl Constant
Sourcepub const BASE64_ENGINE: GeneralPurpose = BASE64_URL_SAFE_NO_PAD
pub const BASE64_ENGINE: GeneralPurpose = BASE64_URL_SAFE_NO_PAD
Thedefault base4 engine used for encoding and decoding keys.
Sourcepub const BINCODE_CONFIG: Configuration<BigEndian>
pub const BINCODE_CONFIG: Configuration<BigEndian>
The default bincode engine used for encoding and decoding data across data streams.
Sourcepub const BUFFER_SIZE: usize = 130_816usize
pub const BUFFER_SIZE: usize = 130_816usize
The default buffer size (defaulting to extra large for now).
Sourcepub const CHALLENGE_SIZE: usize = 32usize
pub const CHALLENGE_SIZE: usize = 32usize
The size of a signature challenge.
Sourcepub const ENCRYPTION_OVERHEAD: usize = 256usize
pub const ENCRYPTION_OVERHEAD: usize = 256usize
The size of the encryption overhead.
Sourcepub const EXCHANGE_PUBLIC_KEY_SIZE: usize = 32usize
pub const EXCHANGE_PUBLIC_KEY_SIZE: usize = 32usize
The size of a key exchange public key.
Sourcepub const IDENTITY_PRIVATE_KEY_LENGTH: usize = 111usize
pub const IDENTITY_PRIVATE_KEY_LENGTH: usize = 111usize
The base64 encoded size of a key exchange private key.
Sourcepub const IDENTITY_PUBLIC_KEY_LENGTH: usize = 43usize
pub const IDENTITY_PUBLIC_KEY_LENGTH: usize = 43usize
The base64 encoded size of a key exchange public key.
Sourcepub const KDF: Algorithm = HKDF_SHA256
pub const KDF: Algorithm = HKDF_SHA256
The algorithm used to produce the shared secret of the key exchange.
Sourcepub const SHARED_SECRET_NONCE_SIZE: usize = 12usize
pub const SHARED_SECRET_NONCE_SIZE: usize = 12usize
The size of the shared secret nonce.
Sourcepub const SHARED_SECRET_SIZE: usize = 32usize
pub const SHARED_SECRET_SIZE: usize = 32usize
The size of the shared secret.
Sourcepub const SHARED_SECRET_TAG_SIZE: usize = 16usize
pub const SHARED_SECRET_TAG_SIZE: usize = 16usize
The size of the shared secret encryption tag.
Sourcepub const SIGNATURE: &'static EdDSAParameters
pub const SIGNATURE: &'static EdDSAParameters
The type of signature used for the handshake.
Sourcepub const SIGNATURE_SIZE: usize = 64usize
pub const SIGNATURE_SIZE: usize = 64usize
The size of the signature used for the handshake.