Type Alias SharedSecret

pub type SharedSecret = SecretBox<SharedSecretShape>;
A helper type for a shared secret.

These are the secrets that each end of the connection will use to encrypt and decrypt data. They are derived from the ephemeral keys, and DH key exchange.

Aliased Type

struct SharedSecret { /* private fields */ }