pub struct BuffedStream<R, W> { /* private fields */ }Expand description
BuffedStream type.
This type is a wrapper around a stream that provides buffering and encryption/decryption functionality. It is used to provide a bincode-centric stream that can be used to send and receive data in a more efficient manner. In order to make usual future splitting more ergonomic, this type is designed to be a wrapper around the split halves.
This type is used to provide a bincode-centric stream that can be used to send and receive data so it is inadvisable to use any other methods than the
pushandpullmethods from the protocol module.
Implementations
Sourceimpl<R, W> BuffedStream<R, W>
impl<R, W> BuffedStream<R, W>
Sourcepub fn with_encryption(self, shared_secret: SharedSecret) -> Self
pub fn with_encryption(self, shared_secret: SharedSecret) -> Self
Sets the shared secret for the stream, and enables encryption / decryption.
Sourceimpl<R, W> BuffedStream<R, W>
impl<R, W> BuffedStream<R, W>
pub fn from_splits(inner_read: R, inner_write: W) -> Self
Sourceimpl<R> BuffedStream<R, OwnedWriteHalf>
impl<R> BuffedStream<R, OwnedWriteHalf>
pub fn as_inner_tcp_write_ref(&self) -> &OwnedWriteHalf
pub fn as_inner_tcp_write_mut(&mut self) -> &mut OwnedWriteHalf
Sourceimpl<W> BuffedStream<OwnedReadHalf, W>
impl<W> BuffedStream<OwnedReadHalf, W>
pub fn as_inner_tcp_read_ref(&self) -> &OwnedReadHalf
pub fn as_inner_tcp_read_mut(&mut self) -> &mut OwnedReadHalf