pub struct BuffedStream<R, W> { /* private fields */ }Expand description
BuffedStream type.
This type is a wrapper around a stream that provides buffering and encryption/decryption functionality. It is used to provide a bincode-centric stream that can be used to send and receive data in a more efficient manner.
This type is used to provide a bincode-centric stream that can be used to send and receive data so it is inadvisable to use any other methods than the
pushandpullmethods from the protocol module. Usingreadandwritedirectly will bypass the normal logic, and should only be used when you know what you are doing (most common use case is pumping data).
The shared_secret field is used to encrypt and decrypt data.
The read_stream field is used to buffer data that has been decrypted.
Implementations
Sourceimpl<R, W> BuffedStream<R, W>
impl<R, W> BuffedStream<R, W>
Sourcepub fn with_encryption(self, shared_secret: SharedSecret) -> Self
pub fn with_encryption(self, shared_secret: SharedSecret) -> Self
Sets the shared secret for the stream, and enables encryption / decryption.
pub fn into_split(self) -> (BuffedStreamReadHalf<R>, BuffedStreamWriteHalf<W>)
Sourceimpl<R, W> BuffedStream<R, W>
impl<R, W> BuffedStream<R, W>
Sourceimpl<R> BuffedStream<R, OwnedWriteHalf>
impl<R> BuffedStream<R, OwnedWriteHalf>
pub fn as_inner_tcp_write_ref(&self) -> &OwnedWriteHalf
Sourceimpl<W> BuffedStream<OwnedReadHalf, W>
impl<W> BuffedStream<OwnedReadHalf, W>
pub fn as_inner_tcp_read_ref(&self) -> &OwnedReadHalf