Protocol message types and serialization.
This module contains the types and serialization methods for the protocol messages.
Structs
- Client
Authentication - Serves as the client’s response to the server’s challenge.
- Client
Preamble - Serves as the preamble for the connection.
- Protocol
Message Guard - The self-referencing struct.
- Protocol
Message Guard Async Builder - A more verbose but stable way to construct self-referencing structs. It is comparable to using
StructName { field1: value1, field2: value2 }rather thanStructName::new(value1, value2). This has the dual benefit of making your code both easier to refactor and more readable. Callbuild()to construct the actual struct. The fields of this struct should be used as follows: - Protocol
Message Guard Async Send Builder - A more verbose but stable way to construct self-referencing structs. It is comparable to using
StructName { field1: value1, field2: value2 }rather thanStructName::new(value1, value2). This has the dual benefit of making your code both easier to refactor and more readable. Callbuild()to construct the actual struct. The fields of this struct should be used as follows: - Protocol
Message Guard Async Send TryBuilder - A more verbose but stable way to construct self-referencing structs. It is comparable to using
StructName { field1: value1, field2: value2 }rather thanStructName::new(value1, value2). This has the dual benefit of making your code both easier to refactor and more readable. Calltry_build()ortry_build_or_recover()to construct the actual struct. The fields of this struct should be used as follows: - Protocol
Message Guard Async TryBuilder - A more verbose but stable way to construct self-referencing structs. It is comparable to using
StructName { field1: value1, field2: value2 }rather thanStructName::new(value1, value2). This has the dual benefit of making your code both easier to refactor and more readable. Calltry_build()ortry_build_or_recover()to construct the actual struct. The fields of this struct should be used as follows: - Protocol
Message Guard Builder - A more verbose but stable way to construct self-referencing structs. It is comparable to using
StructName { field1: value1, field2: value2 }rather thanStructName::new(value1, value2). This has the dual benefit of making your code both easier to refactor and more readable. Callbuild()to construct the actual struct. The fields of this struct should be used as follows: - Protocol
Message Guard TryBuilder - A more verbose but stable way to construct self-referencing structs. It is comparable to using
StructName { field1: value1, field2: value2 }rather thanStructName::new(value1, value2). This has the dual benefit of making your code both easier to refactor and more readable. Calltry_build()ortry_build_or_recover()to construct the actual struct. The fields of this struct should be used as follows: - Server
Preamble - Serves as the server’s response to the preamble, containing its public key, its signature of the client’s challenge and a challenge. The server signs the client’s challenge to prove its identity.
Enums
- Protocol
Error - A helper type for protocol errors.
- Protocol
Message - A helper type for protocol messages.
Traits
- Bincode
Receive - A trait for receiving protocol messages over a stream.
- Bincode
Send - A trait for sending protocol messages over a stream.
Type Aliases
- Challenge
- A helper type for a challenge.
- Exchange
Public Key - A helper type for an ephemeral public key.
- Signature
- A helper type for a signature.