Module protocol

Protocol message types and serialization.

This module contains the types and serialization methods for the protocol messages.

Structs

ClientAuthentication
Serves as the client’s response to the server’s challenge.
ClientPreamble
Serves as the preamble for the connection.
SerializeableSignature
A helper type for serializing signatures (bincode cannot serialize a [u8; 64] our of the box).
ServerPreamble
Serves as the server’s response to the preamble, containing its public key, its signature of the client’s challenge and a challenge.

Enums

ProtocolError
A helper type for protocol errors.
ProtocolMessage
A helper type for protocol messages.
ProtocolMessageWrapper
A wrapper type for protocol messages.

Traits

BincodeMessage
A helper trait for protocol messages.
BincodeReceive
A trait for receiving protocol messages over a stream.
BincodeSend
A trait for sending protocol messages over a stream.

Type Aliases

Challenge
A helper type for a challenge.
ExchangePublicKey
A helper type for an ephemeral public key.
Signature
A helper type for a signature.