Protocol message types and serialization.
This module contains the types and serialization methods for the protocol messages.
Structs
- Client
Authentication - Serves as the client’s response to the server’s challenge.
- Client
Preamble - Serves as the preamble for the connection.
- Serializeable
Signature - A helper type for serializing signatures (bincode cannot serialize a
[u8; 64]our of the box). - Server
Preamble - Serves as the server’s response to the preamble, containing its public key, its signature of the client’s challenge and a challenge.
Enums
- Protocol
Error - A helper type for protocol errors.
- Protocol
Message - A helper type for protocol messages.
- Protocol
Message Wrapper - A wrapper type for protocol messages.
Traits
- Bincode
Message - A helper trait for protocol messages.
- Bincode
Receive - A trait for receiving protocol messages over a stream.
- Bincode
Send - A trait for sending protocol messages over a stream.
Type Aliases
- Challenge
- A helper type for a challenge.
- Exchange
Public Key - A helper type for an ephemeral public key.
- Signature
- A helper type for a signature.