pub enum ProtocolError {
InvalidHost(String),
InvalidKey(String),
RemoteFailed(String),
Unknown(String),
}Expand description
A helper type for protocol errors.
This is used to send and receive errors over the network. It is also used to serialize and deserialize errors.
It should not be sent / received over the network, as it
should be sent as a ProtocolMessage::Error message.
The type system should prevent this from happening.
Variants
Implementations
Sourceimpl ProtocolError
impl ProtocolError
Sourcepub async fn send_and_bail<T, R>(self, stream: &mut T) -> Res<R>where
T: BincodeSend,
pub async fn send_and_bail<T, R>(self, stream: &mut T) -> Res<R>where
T: BincodeSend,
Sends the error message and shuts down the stream.
The generic parameter R represents the return type expected by the calling function. This method always returns an error, but needs to have the expected return type for the context.