Enum ProtocolMessage

pub enum ProtocolMessage {
    ClientPreamble(ClientPreamble),
    ServerPreamble(ServerPreamble),
    ClientAuthentication(ClientAuthentication),
    HandshakeCompletion,
    Data(Vec<u8>),
    UdpData(Vec<u8>),
    Error(ProtocolError),
}
A helper type for protocol messages.

This is the main message type for the protocol. It is used to send and receive messages over the network. It is also used to serialize and deserialize messages.

Variants



ClientPreamble(ClientPreamble)



ServerPreamble(ServerPreamble)



ClientAuthentication(ClientAuthentication)



HandshakeCompletion



Data(Vec<u8>)



UdpData(Vec<u8>)



Error(ProtocolError)

Implementations

Source

impl ProtocolMessage

pub fn fail_if_error(self) -> Res<Self>

Checks if the message is an error.

If it is, returns the message wrapped in an error.