pub trait BincodeSend:
Sink<ProtocolMessage>
+ AsyncWrite
+ AsyncWriteExt
+ Unpin
+ Sized {
// Provided method
fn push(&mut self, message: ProtocolMessage) -> impl Future<Output = Void> { ... }
}Expand description
A trait for sending protocol messages over a stream.
This impl is designed to ensure that the push method can only be used to send
ProtocolMessage messages.
Provided Methods
fn push(&mut self, message: ProtocolMessage) -> impl Future<Output = Void>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.