Keypair generation and resolution.
This module provides functions to generate a keypair, resolve private and public keys from files or strings, and handle errors related to key resolution.
Functions
- ensure_
security_ files - Ensures all required security files are present and generates them if not.
- generate
- Generates a keypair and writes them to the specified location.
- get_
home - Gets the user’s home directory.
- resolve_
authorized_ keys - Resolves to the list of authorized keys.
- resolve_
keypath - Computes the concrete keypath.
- resolve_
known_ hosts - Resolves to the list of known hosts.
- resolve_
private_ key - Resolves the private key of this instance.
- resolve_
public_ key - Resolves the public key of this instance.